@@ -2,8 +2,13 @@
 import sys
 
 from django.db import utils
+from django.conf import settings
 from django.db.backends import BaseDatabaseWrapper, BaseDatabaseFeatures, BaseDatabaseValidation, BaseDatabaseClient
 from django.db.backends.signals import connection_created
+try:
+    from django.utils.timezone import utc
+except:
+    pass
 
 import pytds as Database
 
@@ -71,7 +76,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
         try:
             self.command_timeout = int(self.settings_dict.get('COMMAND_TIMEOUT', 30))
-        except ValueError:   
+        except ValueError:
             self.command_timeout = 30
         
         try:
@@ -94,6 +99,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 autocommit=self.autocommit,
                 use_mars=options.get('use_mars', False),
                 load_balancer=options.get('load_balancer', None),
+                use_tz=utc if settings.USE_TZ else None,
             )
             # The OUTPUT clause is supported in 2005+ sql servers
             self.features.can_return_id_from_insert = self.connection.tds_version >= Database.TDS72
